chrome.runtime.onMessage.addListener(function (message, sender, responseFunction) {
    console.log('Page requested configuration:');
    if (message.action == 'options') {
        console.log('Responding with ' + format.toString() + ' / ' + replacement.toString() + ' / ' + protocol.toString());
        responseFunction({ 'format': format.toString(), 'replacement': replacement.toString(), 'protocol': protocol.toString() });
    }
});

var signalrHubProxy;
preInit();

var format = "(?:(?:(?:(\+?\d{2})(?:[- /\\]?)(\d{2}))|(\d{3}))[- /\\]?(\d{3})[- /\\]?(\d{2})[- /\\]?(\d{2}))".replace(/\\/g, '\\\\').replace(/\+/g, '\\+');
var replacement = '$1$2$3$4$5$6';
var protocol = 'tel';

function preInit() {
    try {
        $.connection.hub.url = 'http://localhost:9562/signalr';
        $.connection.hub.start().done(init);
        signalrHubProxy = $.connection.signalRHub;

        signalrHubProxy.client.registerOk = function () {
            console.log('MyProject registration ok.');
        };

        signalrHubProxy.client.invokeGetUrls = function () {
            chrome.tabs.query({}, function (tabs) {
                console.log('Getting URLs:');
                var tabUrls = new Array();
                for (var i = 0; i < tabs.length; i++) {
                    console.log('  ' + tabs[i].url);
                    tabUrls[i] = tabs[i].url;
                }
                signalrHubProxy.server.getUrls(tabUrls);
            });
        };

        signalrHubProxy.client.setUrl = function (url, oldUrl) {
            chrome.tabs.query({ 'url': oldUrl }, function (tabs) {
                console.log('Browsing to URL ' + url);
                if (tabs.length > 0) {
                    chrome.tabs.update(tabs[0].id, { 'url': url, 'highlighted': true });
                } else {
                    chrome.tabs.create({ 'url': url });
                }
                chrome.windows.getCurrent({}, function (window) {
                    chrome.windows.update(window.id, { 'focused': true });
                });
            });
        };

        signalrHubProxy.client.setFormat = function (newFormat) {
            console.log('Format received from MyProject: ' + newFormat);
            format = newFormat;
        }

        signalrHubProxy.client.setReplacement = function (newReplacement) {
            console.log('Replacement received from MyProject: ' + newReplacement);
            replacement = newReplacement;
        }

        signalrHubProxy.client.setProtocol = function (newProtocol) {
            console.log('Protocol received from MyProject: ' + newProtocol);
            protocol = newProtocol;
        }

        signalrHubProxy.client.disconnect = function () {
            console.log('Disconnected from MyProject');
            $.connection.hub.stop();
            reloadExtension();
        }

    } catch (e) {
        console.log('Could not connect to SignalR hub http://localhost:9562/signalr. Retrying connection in 12 seconds.');
        reloadExtension();
    }
}

function init() {
    signalrHubProxy.server.register();
    console.log('Requesting configuration from MyProject...');

    signalrHubProxy.server.getPhoneNumberFormat();
    signalrHubProxy.server.getPhoneNumberReplacement();
    signalrHubProxy.server.getProtocol();
}

function reloadExtension() {
    setTimeout(function () { chrome.runtime.reload(); }, 12000);
}
